@@ -2,6 +2,7 @@
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
+from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
 from .managers import FavoriteManager
@@ -11,7 +12,7 @@ class Favorite(models.Model):
     """
     """
 
-    user = models.ForeignKey('auth.User')
+    user = models.ForeignKey(getattr(settings, 'AUTH_USER_MODEL', 'auth.User'))
     target_content_type = models.ForeignKey(ContentType)
     target_object_id = models.PositiveIntegerField()
     target = generic.GenericForeignKey('target_content_type', 'target_object_id')
