@@ -1,27 +1,4 @@
 $(document).ready(function() {
-  function getCookie(name) {
-      var cookieValue = null;
-      if (document.cookie && document.cookie != '') {
-          var cookies = document.cookie.split(';');
-          for (var i = 0; i < cookies.length; i++) {
-              var cookie = jQuery.trim(cookies[i]);
-              // Does this cookie string begin with the name we want?
-              if (cookie.substring(0, name.length + 1) == (name + '=')) {
-                  cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
-                  break;
-              }
-          }
-      }
-      return cookieValue;
-  }
-
-  var csrftoken = getCookie('csrftoken');
-  $.ajaxSetup({
-      beforeSend: function(xhr) {
-      xhr.setRequestHeader("X-CSRFToken", csrftoken);
-      }
-  });
-
   $('.btn.favorite').click(function() {
       var $obj = $(this);
       var target_id = $obj.attr('id').split('_')[1];
